==> v_sim-3.1.2.tar.bz2: v_sim-3.1.2/src/callbacks.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2005)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/
#include <gtk/gtk.h>


/* id of the changed signal connected to the combobox.
   It has to be disable when a tab is changed to avoid
   infinite loops since a changed in tab makes a change
   in the combo box. */
gulong comboListeSubPanelSignalChanged;
/* Callback function of the combobox */
void comboChanged(GtkEditable *entry, gpointer data);
/* id of the changed signal connected to the subpanel. */
gulong tabSubPanelSignalChanged;
/* Callback function of the notebook. */
void subPanelChanged(GtkNotebook *book, GtkNotebookPage *page,
		     guint num, gpointer data);


void
on_loadButton_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_saveButton_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_cancelButtonSave_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_okButtonSave_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_checkbuttonParameter_toggled        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_checkButtonResources_toggled        (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_cancelButtonSave_clicked            (GtkButton       *button,
                                        gpointer         user_data);

void
on_visuAbout_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_scanResourcesButton_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_redrawButton_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_observeButton_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void stopPickObserveGtk();

void
on_closebutton1_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_radioObserve_toggled                (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_radioPick_toggled                   (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

void
on_spinTheta_value_changed             (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_spinDx_value_changed                (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_spinGross_value_changed             (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_spinPhi_value_changed               (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_spinDy_value_changed                (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_spinPersp_value_changed             (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_dumpButton_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_pairsButton_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_closebutton3_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_checkDrawPairs_toggled              (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_pairsDialog_destroy_event           (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_pairsDialog_close                   (GtkDialog       *dialog,
                                        gpointer         user_data);

gboolean
on_pairsDialog_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_buttonOpenParameters_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_buttonOpenResources_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_spinOmega_value_changed             (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

==> v_sim-3.2.1.tar.bz2: v_sim-3.2.1/src/callbacks.h <==
/*   EXTRAITS DE LA LICENCE
	Copyright CEA, contributeurs : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2006)
  
	Adresse ml :
	BILLARD, non joignable par ml ;
	CALISTE, damien P caliste AT cea P fr.

	Ce logiciel est un programme informatique servant  visualiser des
	structures atomiques dans un rendu pseudo-3D. 

	Ce logiciel est rgi par la licence CeCILL soumise au droit franais et
	respectant les principes de diffusion des logiciels libres. Vous pouvez
	utiliser, modifier et/ou redistribuer ce programme sous les conditions
	de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA 
	sur le site "http://www.cecill.info".

	Le fait que vous puissiez accder  cet en-tte signifie que vous avez 
	pris connaissance de la licence CeCILL, et que vous en avez accept les
	termes (cf. le fichier Documentation/licence.fr.txt fourni avec ce logiciel).
*/

/*   LICENCE SUM UP
	Copyright CEA, contributors : Luc BILLARD et Damien
	CALISTE, laboratoire L_Sim, (2001-2006)

	E-mail address:
	BILLARD, not reachable any more ;
	CALISTE, damien P caliste AT cea P fr.

	This software is a computer program whose purpose is to visualize atomic
	configurations in 3D.

	This software is governed by the CeCILL  license under French law and
	abiding by the rules of distribution of free software.  You can  use, 
	modify and/ or redistribute the software under the terms of the CeCILL
	license as circulated by CEA, CNRS and INRIA at the following URL
	"http://www.cecill.info". 

	The fact that you are presently reading this means that you have had
	knowledge of the CeCILL license and that you accept its terms. You can
	find a copy of this licence shipped with this software at Documentation/licence.en.txt.
*/
#include <gtk/gtk.h>


/* id of the changed signal connected to the combobox.
   It has to be disable when a tab is changed to avoid
   infinite loops since a changed in tab makes a change
   in the combo box. */
gulong comboboxListeSubPanelSignalChanged;
/* Callback function of the combobox */
void comboboxChanged(GtkComboBox *combo, gpointer data);
/* id of the changed signal connected to the subpanel. */
gulong tabSubPanelSignalChanged;
/* Callback function of the notebook. */
void subPanelChanged(GtkNotebook *book, GtkNotebookPage *page,
		     guint num, gpointer data);


void
on_loadButton_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_saveButton_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_visuAbout_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

void
on_observeButton_clicked               (GtkButton       *button,
                                        gpointer         user_data);

void
on_spinTheta_value_changed             (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_spinDx_value_changed                (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_spinGross_value_changed             (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_spinPhi_value_changed               (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_spinDy_value_changed                (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_spinPersp_value_changed             (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);

void
on_pairsButton_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_closebutton3_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_checkDrawPairs_toggled              (GtkToggleButton *togglebutton,
                                        gpointer         user_data);

gboolean
on_pairsDialog_destroy_event           (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_pairsDialog_close                   (GtkDialog       *dialog,
                                        gpointer         user_data);

gboolean
on_pairsDialog_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_buttonOpenParameters_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_buttonOpenResources_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_spinOmega_value_changed             (GtkSpinButton   *spinbutton,
                                        gpointer         user_data);
